// Copyright (c) 2011-2022  Made to Order Software Corp.  All Rights Reserved
//
// https://snapwebsites.org/project/fluid-settings
// contact@m2osw.com
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

/** \file
 * \brief The version of the fluid settings library at compile time.
 *
 * This file records the fluid settings library version at
 * compile time.
 *
 * The `#define`s give you the library version at the time you are compiling.
 * The functions allow you to retrieve the version of a dynamically linked
 * library.
 */

// self
//
#include    "fluid_window.h"


// fluid-settings
//
#include    <fluid-settings/version.h>


// advgetopt
//
#include    <advgetopt/exception.h>


// libexcept
//
#include    <libexcept/file_inheritance.h>


// snaplogger
//
#include    <snaplogger/message.h>


// eventdispatcher
//
#include    <eventdispatcher/signal_handler.h>


// libexcept
//
#include    <libexcept/file_inheritance.h>


// Qt
//
#include    <QApplication>


// last include
//
#include    <snapdev/poison.h>






int main(int argc, char * argv[])
{
    ed::signal_handler::create_instance();
    libexcept::verify_inherited_files();

    try
    {
        QApplication app(argc, argv);
        app.setApplicationName("Fluid Settings");
        app.setApplicationVersion(FLUID_SETTINGS_VERSION_STRING);
        app.setOrganizationDomain("https://www.snapwebsites.org");
        app.setOrganizationName("Snap! Websites");

        FluidWindow win(argc, argv, app);
        win.show();
        return win.run();
    }
    catch(advgetopt::getopt_exit const & e)
    {
        return e.code();
    }
    catch(std::exception const & e)
    {
        SNAP_LOG_EXCEPTION
            << "error: an exception occurred: "
            << e
            << SNAP_LOG_SEND;
    }

    return 1;
}


// vim: ts=4 sw=4 et
